meters_to_decdeg converts from meters to degrees at a specified
position on the globe. The use case this function was developed for was to
calculate occurence point uncertainty values, which are usually reported in
meters, as degrees.
The formula for converting from meters to decimal degrees is in part based on information from the ESRI ArcUser magazine at this site https://www.esri.com/news/arcuser/0400/wdside.html
meters_to_decdeg(
occs_df,
lat_col = "latitude",
lon_col = "longitude",
distance,
na_action = "NA as 0"
)dist_dd A data.frame of latitude and longitude distances in
units of degree decimal.
A data.frame of occurrence locations that incudes
at least these three columns - latitude, longitude, and a distance
in meters to be converted to decimal degrees.
Name of column of latitude values. Caps sensitive.
Name of column of longitude values. Caps sensitive.
Name of column of distance values, in meters. Caps sensitive.
Enact distance options for NA values. Caps sensitive